==> lxqt-panel_0.17.1.orig.tar.xz: lxqt-panel-0.17.1/plugin-statusnotifier/translations/statusnotifier_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation>Настройки плагина уведомлений</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="28"/>
        <location filename="../statusnotifierconfiguration.ui" line="38"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation>Элемент, для которого включено автоскрытие, будет оставаться видимым в течении этого периода, если он требует к себе внимания.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="31"/>
        <source>Attention period:</source>
        <translation>Период внимания:</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="41"/>
        <source> minute(s)</source>
        <translation> мин.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="72"/>
        <source>Change visibility of items</source>
        <translation>Изменить видимость элементов</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="85"/>
        <source>Item</source>
        <translation>Элемент</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="90"/>
        <source>Visibility</source>
        <translation>Видимость</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always show</source>
        <translation>Всегда показывать</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Auto-hide</source>
        <translation>Автоматически скрывать</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="84"/>
        <source>Always hide</source>
        <translation>Всегда скрывать</translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.1.4.orig.tar.xz: lxqt-panel-2.1.4/plugin-statusnotifier/translations/statusnotifier_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation>Настройки плагина уведомлений</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="25"/>
        <source>Reverse the order of items</source>
        <translation>Уведомления в обратном порядке</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="39"/>
        <location filename="../statusnotifierconfiguration.ui" line="49"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation>Элемент, для которого включено автоскрытие, будет оставаться видимым в течении этого периода, если он требует к себе внимания.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="42"/>
        <source>Attention period:</source>
        <translation>Период внимания:</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="52"/>
        <source> minute(s)</source>
        <translation> мин.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="83"/>
        <source>Change visibility of items</source>
        <translation>Изменить видимость элементов</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="96"/>
        <source>Item</source>
        <translation>Элемент</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="101"/>
        <source>Visibility</source>
        <translation>Видимость</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always show</source>
        <translation>Всегда показывать</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Auto-hide</source>
        <translation>Автоматически скрывать</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always hide</source>
        <translation>Всегда скрывать</translation>
    </message>
</context>
</TS>
